<?php

class Auth {
    private $conn;

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    // Fungsi untuk login
    public function login($username, $password) {
        // Query untuk mendapatkan data user berdasarkan username
        $stmt = $this->conn->prepare("SELECT * FROM tbl_user WHERE username_user = ?");
        if (!$stmt) {
            die("Error in query preparation: " . $this->conn->error);
        }

        $stmt->bind_param("s", $username);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();

            // Verifikasi password
            if (password_verify($password, $user['password_user'])) {
                return $user; // Mengembalikan data user
            }
        }

        // Jika login gagal
        return false;
    }

    // Fungsi untuk registrasi
    public function register($username, $email, $password, $role = 'user') {
        // Periksa apakah username sudah ada
        $sqlCheck = "SELECT id_user FROM tbl_user WHERE username_user = ?";
        $stmtCheck = $this->conn->prepare($sqlCheck);

        if ($stmtCheck) {
            $stmtCheck->bind_param('s', $username);
            $stmtCheck->execute();
            $stmtCheck->store_result();

            if ($stmtCheck->num_rows > 0) {
                $stmtCheck->close();
                return [
                    'success' => false,
                    'message' => 'Username sudah digunakan.'
                ];
            }
            $stmtCheck->close();
        }

        // Hash password
        $hashedPassword = password_hash($password, PASSWORD_BCRYPT);

        // Masukkan data ke database
        $sqlInsert = "INSERT INTO tbl_user (username_user, email_user, password_user, role_user) VALUES (?, ?, ?, ?)";
        $stmtInsert = $this->conn->prepare($sqlInsert);

        if ($stmtInsert) {
            $stmtInsert->bind_param('ssss', $username, $email, $hashedPassword, $role);

            if ($stmtInsert->execute()) {
                $stmtInsert->close();
                return [
                    'success' => true,
                    'message' => 'Registrasi berhasil. Silakan login.'
                ];
            } else {
                $stmtInsert->close();
                return [
                    'success' => false,
                    'message' => 'Terjadi kesalahan pada sistem.'
                ];
            }
        }
        return [
            'success' => false,
            'message' => 'Terjadi kesalahan pada sistem.'
        ];
    }

    public function __destruct() {
        if ($this->conn) {
            $this->conn->close();
        }
    }
}
?>