<?php

class Product {
    private $conn;

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    // Menambah produk baru
    public function addProduct($nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $img_kendaraan) {
        $query = "INSERT INTO tbl_kendaraan (nama_kendaraan, stok_kendaraan, harga_kendaraan, img_kendaraan) VALUES (?, ?, ?, ?)";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("sdis", $nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $img_kendaraan);
        return $stmt->execute();
    }

    // Menghapus produk berdasarkan ID
    public function deleteProduct($id) {
        // Mengambil nama gambar untuk dihapus
        $stmt = $this->conn->prepare("SELECT img_kendaraan FROM tbl_kendaraan WHERE id_kendaraan = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();

        if ($row && $row['img_kendaraan']) {
            unlink(__DIR__ . '../assets/img/' . $row['img_kendaraan']);
        }

        // Menghapus data produk
        $stmt = $this->conn->prepare("DELETE FROM tbl_kendaraan WHERE id_kendaraan = ?");
        $stmt->bind_param("i", $id);

        if ($stmt->execute()) {
            return true;
        } else {
            return $stmt->error;
        }
    }

    // Memperbarui produk
    public function updateProduct($id, $nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $img_kendaraan = null, $old_img_kendaraan = null) {
        if ($img_kendaraan) {
            // Hapus gambar lama jika ada gambar baru
            if ($old_img_kendaraan) {
                unlink(__DIR__ . '../assets/img/' . $old_img_kendaraan);
            }

            $stmt = $this->conn->prepare("UPDATE tbl_kendaraan SET nama_kendaraan = ?, img_kendaraan = ?, stok_kendaraan = ?, harga_kendaraan = ? WHERE id_kendaraan = ?");
            $stmt->bind_param("ssiii", $nama_kendaraan, $img_kendaraan, $stok_kendaraan, $harga_kendaraan, $id);
        } else {
            $stmt = $this->conn->prepare("UPDATE tbl_kendaraan SET nama_kendaraan = ?, stok_kendaraan = ?, harga_kendaraan = ? WHERE id_kendaraan = ?");
            $stmt->bind_param("siii", $nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $id);
        }

        if ($stmt->execute()) {
            return true;
        } else {
            return $stmt->error;
        }
    }

    // mendapatkan product berdasarkan id
    public function getProductById($vehicleId) {
        $sql = "SELECT * FROM tbl_kendaraan WHERE id_kendaraan = ?";
        $stmt = $this->conn->prepare($sql);
        $stmt->bind_param("i", $vehicleId);
        $stmt->execute();
        $result = $stmt->get_result();
        return $result->fetch_assoc();
    }

    // Mendapatkan semua produk
    public function getAllProducts() {
        $query = "SELECT * FROM tbl_kendaraan";
        $result = $this->conn->query($query);

        if ($result->num_rows > 0) {
            return $result->fetch_all(MYSQLI_ASSOC);
        } else {
            return [];
        }
    }
}
?>