<?php

class Pesanan {
    private $conn;

    // Konstruktor: Menghubungkan ke database
    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    public function buatPesanan($userId, $name, $phone, $startDate, $endDate, $vehicleId, $paymentMethod, $totalPrice) {
        $this->conn->begin_transaction();

        try {
            $createdAt = date("Y-m-d H:i:s"); // Waktu sekarang
            $insertQuery = "INSERT INTO tbl_pesanan (id_user, nama_penyewa, nomor_telepon, tgl_pinjam, tgl_kembali, id_kendaraan, id_pembayaran, total_pesanan, status_pesanan, created_at) 
                            VALUES (?, ?, ?, ?, ?, ?, ?, ?, 'belum bayar', ?)";
            $stmt = $this->conn->prepare($insertQuery);
            $stmt->bind_param("issssiiis", $userId, $name, $phone, $startDate, $endDate, $vehicleId, $paymentMethod, $totalPrice, $createdAt);
            $stmt->execute();

            // Kurangi stok kendaraan
            $updateStockQuery = "UPDATE tbl_kendaraan SET stok_kendaraan = stok_kendaraan - 1 WHERE id_kendaraan = ?";
            $stmt = $this->conn->prepare($updateStockQuery);
            $stmt->bind_param("i", $vehicleId);
            $stmt->execute();

            $this->conn->commit();
            return true;
        }
            catch (Exception $e) {
            $this->conn->rollback();
            return false;
        }
    }

    // Metode untuk membatalkan pesanan otomatis jika status "belum bayar" lebih dari 1 jam
    public function autoCancelOrders() {
        $query = "SELECT id_pesanan, id_kendaraan FROM tbl_pesanan 
                  WHERE status_pesanan = 'belum bayar' 
                  AND TIMESTAMPDIFF(MINUTE, created_at, NOW()) > 60";
        $result = $this->conn->query($query);

        if ($result->num_rows > 0) {
            while ($order = $result->fetch_assoc()) {
                $this->updateStock($order['id_kendaraan'], 1); // Kembalikan stok kendaraan
                $this->updateOrderStatus($order['id_pesanan'], 'batal'); // Ubah status menjadi batal
            }
        }
    }

    // Metode untuk memperbarui status pesanan
    public function updateOrderStatus($idPesanan, $status) {
        $query = "UPDATE tbl_pesanan SET status_pesanan = ? WHERE id_pesanan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("si", $status, $idPesanan);
        $stmt->execute();
    }

    // Metode untuk memperbarui bukti Pembayaran
    public function updateBuktiPembayaran($idPesanan, $buktiPembayaran) {
        $query = "UPDATE tbl_pesanan SET bukti_Pembayaran = ? WHERE id_pesanan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("si", $buktiPembayaran, $idPesanan);
        return $stmt->execute();
    }

    // Metode untuk memperbarui stok kendaraan
    public function updateStock($idKendaraan, $increment) {
        $query = "UPDATE tbl_kendaraan SET stok_kendaraan = stok_kendaraan + ? WHERE id_kendaraan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("ii", $increment, $idKendaraan);
        $stmt->execute();
    }

    // Metode untuk mendapatkan semua pesanan
    public function getAllOrders() {
        $query = "SELECT p.id_pesanan, p.nama_penyewa, p.nomor_telepon, p.total_pesanan, p.status_pesanan, 
                   k.nama_kendaraan, pm.nama_pembayaran, p.bukti_pembayaran
            FROM tbl_pesanan p
            JOIN tbl_kendaraan k ON p.id_kendaraan = k.id_kendaraan
            JOIN tbl_pembayaran pm ON p.id_pembayaran = pm.id_pembayaran
            WHERE p.status_pesanan != 'riwayat'";  // Tambahkan kondisi ini
        $stmt = $this->conn->prepare($query);
        $stmt->execute();
        return $stmt->get_result();
    }    

    // Metode untuk mendapatkan data pesanan berdasarkan ID
    public function getOrderById($idPesanan) {
        $query = "SELECT * FROM tbl_pesanan WHERE id_pesanan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("i", $idPesanan);
        $stmt->execute();
        $result = $stmt->get_result();
        return $result->fetch_assoc();
    }

    public function getOrdersByStatus($status) {
        $query = "SELECT p.id_pesanan, p.nama_penyewa, p.nomor_telepon, p.total_pesanan, p.status_pesanan, 
                   k.nama_kendaraan, pm.nama_pembayaran, p.bukti_pembayaran
            FROM tbl_pesanan p
            JOIN tbl_kendaraan k ON p.id_kendaraan = k.id_kendaraan
            JOIN tbl_pembayaran pm ON p.id_pembayaran = pm.id_pembayaran
            WHERE p.status_pesanan = ?
        ";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("s", $status);
        $stmt->execute();
        return $stmt->get_result();
    }    

    // Metode untuk menghitung jumlah pesanan berdasarkan status
    public function countOrdersByStatus($status) {
        $query = "SELECT COUNT(*) as jumlah FROM tbl_pesanan WHERE status_pesanan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("s", $status);
        $stmt->execute();
        $result = $stmt->get_result();
        return $result->fetch_assoc()['jumlah'];
    }
    public function getAllOrdersExcludingStatus($status) {
        $sql = "SELECT * FROM tbl_pesanan 
            INNER JOIN tbl_kendaraan ON tbl_pesanan.id_kendaraan = tbl_kendaraan.id_kendaraan
            INNER JOIN tbl_pembayaran ON tbl_pesanan.id_pembayaran = tbl_pembayaran.id_pembayaran
            WHERE tbl_pesanan.status_pesanan != ?";
        $stmt = $this->conn->prepare($sql);
        $stmt->bind_param("s", $status);
        $stmt->execute();
        return $stmt->get_result();
    }

    // Metode untuk menghapus pesanan
    public function deleteOrder($idPesanan) {
        $query = "DELETE FROM tbl_pesanan WHERE id_pesanan = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("i", $idPesanan);
        $stmt->execute();
    }
    public function updateReturnDate($id_pesanan) {
        // Ambil data pesanan untuk mendapatkan id_kendaraan
        $order = $this->getOrderById($id_pesanan);
        if ($order) {
            // Mengupdate status pesanan menjadi riwayat dan tanggal pengembalian
            $query = "UPDATE tbl_pesanan SET tgl_kembali = NOW(), status_pesanan = 'riwayat' WHERE id_pesanan = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->bind_param('i', $id_pesanan);
            $stmt->execute();
    
            // Mengembalikan stok kendaraan
            $this->updateStock($order['id_kendaraan'], 1); // Stok kendaraan bertambah 1
    
            return $stmt->affected_rows > 0;
        }
        return false;
    }        
}
?>
