<?php

class User {
   private $conn;

    public function __construct() {
        $database = new Database();
        $this->conn = $database->getConnection();
    }

    public function getUserById($id) {
        $query = "SELECT * FROM tbl_user WHERE id_user = ?";
        $stmt = $this->conn->prepare($query);
        $stmt->bind_param("i", $id);
        $stmt->execute();
        return $stmt->get_result()->fetch_assoc();
    }

    public function isAdmin($userId) {
        $user = $this->getUserById($userId);
        return $user && $user['role_user'] === 'admin';
    }

    public function countUsers() {
        $query = "SELECT COUNT(*) AS total FROM tbl_user";
        return $this->conn->query($query)->fetch_assoc()['total'];
    }
    
    public function deleteUser($id_user) {
        try {
            $query = "DELETE FROM tbl_user WHERE id_user = ?";
            $stmt = $this->conn->prepare($query);
            $stmt->bind_param("i", $id_user);
        
            if ($stmt->execute()) {
                return true;
            } else {
                return false;
            }
        } catch (Exception $e) {
            throw new Exception("Terjadi kesalahan saat menghapus pengguna: " . $e->getMessage());
        }
    }

    public function getAllUsers() {
        $query = "SELECT id_user, username_user, email_user, role_user FROM tbl_user";
        $result = $this->conn->query($query);
    
        if (!$result) {
            throw new Exception("Query gagal dijalankan: " . $this->conn->error);
        }
    
        $users = [];
        while ($row = $result->fetch_assoc()) {
            $users[] = $row;
        }
    
        return $users;
    }
}

?>