<?php
session_start();

// Periksa apakah pengguna sudah login
if (isset($_SESSION['user'])) {
    header("Location: home.php");
    exit();
}

// Inisialisasi variabel untuk status login
$is_logged_in = isset($_SESSION['user']);

require_once 'classes/database.php';
require_once 'classes/Product.php';

// Inisialisasi kelas Product
$product = new Product();

// Mengambil semua data kendaraan
$vehicles = $product->getAllProducts();

if (!$vehicles) {
    $vehicles = []; // Jika tidak ada data, set menjadi array kosong
}
?>

<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard - Sewa Kendaraan</title>
    <link href="assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="assets/css/style.css"> 
</head>

<body>
    <!-- Navbar -->
<nav class="navbar navbar-expand-lg navbar-dark fixed-top shadow-sm" id="mainNavbar">
    <div class="container">
        <!-- Tambahkan Logo -->
        <a class="navbar-brand fw-bold text-uppercase d-flex align-items-center" href="#">
            <img src="assets/img/Logo_S2R.png" alt="S2R Rental" class="me-2" style="width: 40px; height: 40px;">
            S2R Motor
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav ms-auto">
                <li class="nav-item"><a class="nav-link text-white" href="#vehicles">Daftar Kendaraan</a></li>
                <li class="nav-item"><a class="nav-link text-white" href="#about-us">Tentang Kami</a></li>
                <li class="nav-item"><a class="nav-link text-white" href="#syaratketentuan">Syarat & Ketentuan</a></li>
                <li class="nav-item"><a class="nav-link text-white" href="views/public/pesanan-saya.php">Pesanan Saya</a></li>
                <li class="nav-item"><a class="btn btn-danger text-white ms-2" href="views/auth/login.php">login</a></li>
            </ul>
        </div>
    </div>
</nav>

<style>
    /* Efek transisi halus */
    #mainNavbar {
        transition: background-color 0.5s ease, box-shadow 0.5s ease;
    }

    /* Navbar awal transparan */
    .navbar-transparent {
        background-color: rgba(0, 0, 0, 0.06);
    }

    /* Navbar setelah scroll (lebih gelap) */
    .navbar-darkened {
        background-color: rgba(0, 0, 0, 0.66);
        box-shadow: 0 4px 6px rgba(0, 0, 0, 0.67);
    }
</style>

<script>
    // JavaScript untuk mengatur animasi perubahan warna navbar saat scroll
    document.addEventListener("scroll", function () {
        const navbar = document.getElementById("mainNavbar");
        if (window.scrollY > 50) {
            navbar.classList.add("navbar-darkened");
            navbar.classList.remove("navbar-transparent");
        } else {
            navbar.classList.add("navbar-transparent");
            navbar.classList.remove("navbar-darkened");
        }
    });

    // Pastikan navbar transparan saat halaman pertama kali dimuat
    window.addEventListener("DOMContentLoaded", function () {
        const navbar = document.getElementById("mainNavbar");
        navbar.classList.add("navbar-transparent");
    });
</script>



    <!-- Header -->
    <?php include('views/components/header.php'); ?>

    <!-- Daftar Kendaraan -->
<div class="container py-5 mt-5" id="vehicles">
    <h2 class="text-center mb-4 title-vehicles text-uppercase fw-bold text-dark">Daftar Kendaraan</h2>
    <p class="text-center text-muted fs-5">Pilih kendaraan terbaik untuk perjalanan Anda!</p>
    <div class="row g-4">
        <?php foreach ($vehicles as $vehicle): ?>
            <div class="col-md-4">
                <div class="card vehicle-card shadow-lg border-0 hover-zoom wow fadeInUp" data-wow-delay="0.2s">
                    <div class="position-relative">
                        <img src="<?php echo htmlspecialchars($vehicle['img_kendaraan']); ?>"
                            class="card-img-top vehicle-img rounded-top"
                            alt="<?php echo htmlspecialchars($vehicle['nama_kendaraan']); ?>" />
                        <div class="badge bg-<?php echo $vehicle['stok_kendaraan'] > 0 ? 'success' : 'danger'; ?> position-absolute top-0 start-0 m-3 p-2 fs-6">
                            <?php echo $vehicle['stok_kendaraan'] > 0 ? 'Tersedia' : 'Habis'; ?>
                        </div>
                    </div>
                    <div class="card-body bg-light rounded-bottom">
                        <h5 class="card-title vehicle-title text-primary fw-bold">
                            <?php echo htmlspecialchars($vehicle['nama_kendaraan']); ?>
                        </h5>
                        <p class="card-text">Harga per hari: 
                            <span class="fw-bold text-success">Rp <?php echo number_format($vehicle['harga_kendaraan'], 0, ',', '.'); ?></span>
                        </p>
                        <?php if ($vehicle['stok_kendaraan'] > 0): ?>
                            <a href="<?php echo $is_logged_in ? 'views/public/memesan.php?id=' . $vehicle['id_kendaraan'] : 'views/auth/login.php'; ?>"
                                class="btn btn-success w-100 text-uppercase">
                                Pesan Sekarang
                            </a>
                        <?php else: ?>
                            <span class="btn btn-secondary disabled w-100 text-uppercase">Tidak Tersedia</span>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>

<!-- Tentang Kami (About Us) -->
<div class="container my-5 py-4" id="about-us" style="background-color: #f8f9fa; border-radius: 10px;">
    <h2 class="text-center text-primary mb-4 text-uppercase fw-bold">Tentang Kami</h2>
    <p class="text-center text-muted fs-5 px-3">S2R Rental adalah perusahaan yang menyediakan layanan sewa kendaraan
        berkualitas dengan harga yang terjangkau. Kami berkomitmen untuk memberikan kenyamanan dan kepuasan bagi
        pelanggan kami dengan berbagai pilihan motor. Kami menjamin pelayanan yang cepat, aman, dan terpercaya.</p>
</div>

<!-- Syarat & Ketentuan -->
<div class="container my-5 py-4" id="syaratketentuan">
    <h2 class="text-center text-primary mb-4 title-terms text-uppercase fw-bold">Peraturan Penggunaan</h2>
    <div class="row justify-content-center">
        <div class="col-md-8">
            <ul class="list-group">
                <li class="list-group-item d-flex align-items-center">
                    <i class="bi bi-person-fill text-primary me-3 fs-4"></i>
                    <span class="fs-5">Pengguna harus berusia minimal 18 tahun.</span>
                </li>
                <li class="list-group-item d-flex align-items-center">
                    <i class="bi bi-check-circle-fill text-success me-3 fs-4"></i>
                    <span class="fs-5">Informasi yang diberikan harus akurat dan benar.</span>
                </li>
                <li class="list-group-item d-flex align-items-center">
                    <i class="bi bi-exclamation-circle-fill text-warning me-3 fs-4"></i>
                    <span class="fs-5">Website tidak bertanggung jawab atas kerugian akibat kesalahan pengguna.</span>
                </li>
            </ul>
        </div>
    </div>
</div>

<style>
    /* Efek hover untuk kartu kendaraan */
    .vehicle-card {
        transition: transform 0.3s ease, box-shadow 0.3s ease;
    }

    .vehicle-card:hover {
        transform: scale(1.05);
        box-shadow: 0 10px 20px rgba(0, 0, 0, 0.15);
    }

    /* Efek zoom pada gambar */
    .vehicle-card .vehicle-img {
        transition: transform 0.3s ease;
    }

    .vehicle-card:hover .vehicle-img {
        transform: scale(1.1);
    }

    /* Warna untuk judul */
    .title-vehicles, .title-terms {
        color: #343a40;
    }
</style>

    <!-- Footer -->
    <?php include('views/components/footer.php'); ?>

    <script src="assets/js/bootstrap.bundle.min.js"></script>
    <!-- Include WOW.js -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/wow/1.1.2/wow.min.js"></script>
    <script>
        new WOW().init();
    </script>
</body>

</html>