<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/user.php';

// Periksa autentikasi
if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php');
    exit;
}

// Periksa role admin
if ($_SESSION['user']['role'] !== 'admin') {
    header('Location: ../public/home.php');
    exit;
}

// Inisialisasi kelas Database dan User
$db = new Database();
$conn = $db->getConnection();
$userManager = new User($conn);

// Fungsi untuk menghapus pengguna
if (isset($_GET['delete_id'])) {
    $id_user = $_GET['delete_id'];

    try {
        $isDeleted = $userManager->deleteUser($id_user);
        if ($isDeleted) {
            header("Location: akun.php?delete_success=true");
            exit;
        } else {
            header("Location: akun.php?delete_success=false");
            exit;
        }
    } catch (Exception $e) {
        die("Terjadi kesalahan: " . $e->getMessage());
    }
}

try {
    // Ambil semua pengguna menggunakan kelas User
    $users = $userManager->getAllUsers();
} catch (Exception $e) {
    die("Terjadi kesalahan: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Daftar Pengguna</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/akun.css"> 
</head>

<body>

    <!-- Sidebar -->
    <?php include('../components/sidebar.php'); ?>

    <div class="container mt-4">
        <h1 class="mb-4">Daftar Pengguna</h1>
        <table class="table table-striped">
            <thead class="table-primary">
                <tr>
                    <th>No</th>
                    <th>Username</th>
                    <th>Email</th>
                    <th>Role</th>
                    <th>Aksi</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($users)): ?>
                    <?php foreach ($users as $index => $user): ?>
                        <tr>
                            <td><?= $index + 1; ?></td>
                            <td><?= htmlspecialchars($user['username_user']); ?></td>
                            <td><?= htmlspecialchars($user['email_user']); ?></td>
                            <td><?= htmlspecialchars($user['role_user']); ?></td>
                            <td>
                                <!-- Tombol Hapus -->
                                <button class="btn btn-danger btn-sm" onclick="confirmDelete(<?= $user['id_user']; ?>)">Hapus</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="5" class="text-center">Tidak ada data pengguna.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz"
        crossorigin="anonymous"></script>

    <script>
        function confirmDelete(userId) {
            Swal.fire({
                title: 'Apakah Anda yakin?',
                text: 'Akun ini akan dihapus!',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Hapus',
                cancelButtonText: 'Batal'
            }).then((result) => {
                if (result.isConfirmed) {
                    // Redirect ke halaman untuk menghapus akun
                    window.location.href = 'akun.php?delete_id=' + userId;
                }
            });
        }

        <?php if (isset($_GET['delete_success']) && $_GET['delete_success'] == 'true'): ?>
            Swal.fire({
                title: 'Sukses!',
                text: 'Akun pengguna berhasil dihapus.',
                icon: 'success',
                confirmButtonText: 'OK'
            });
        <?php elseif (isset($_GET['delete_success']) && $_GET['delete_success'] == 'false'): ?>
            Swal.fire({
                title: 'Gagal!',
                text: 'Akun pengguna gagal dihapus.',
                icon: 'error',
                confirmButtonText: 'OK'
            });
        <?php endif; ?>
    </script>
</body>
</html>
