<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/pesanan.php';

// Periksa apakah pengguna telah login
if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php'); // Redirect ke halaman login jika belum login
    exit;
}

// Periksa apakah role user adalah admin
if ($_SESSION['user']['role'] !== 'admin') {
    header('Location: ../public/home.php'); // Redirect ke halaman utama jika bukan admin
    exit;
}

// Inisialisasi koneksi database
$database = new Database();
$conn = $database->getConnection();

// Inisialisasi kelas Pesanan
$pesanan = new Pesanan($conn);

// Proses otomatis: batalkan pesanan "belum bayar" lebih dari 1 jam
$pesanan->autoCancelOrders();

// Tangani aksi berdasarkan parameter di URL
if (isset($_GET['action']) && isset($_GET['id_pesanan'])) {
    $action = $_GET['action'];
    $orderId = $_GET['id_pesanan'];

    if ($action === 'acc') {
        $pesanan->updateOrderStatus($orderId, 'sukses');
        $message = "Pesanan berhasil dikonfirmasi.";
    } elseif ($action === 'cancel') {
        $order = $pesanan->getOrderById($orderId);
        if ($order) {
            $pesanan->updateStock($order['id_kendaraan'], 1);
            $pesanan->updateOrderStatus($orderId, 'batal');
            $message = "Pesanan berhasil dibatalkan.";
        }
    } elseif ($action === 'delete') {
        $pesanan->deleteOrder($orderId);
        $message = "Pesanan berhasil dihapus.";
    } elseif ($action === 'riwayat') {
        $order = $pesanan->getOrderById($orderId);
        if ($order) {
            if ($pesanan->updateReturnDate($orderId)) {
                $message = "Pesanan berhasil dikonfirmasi sebagai riwayat.";
            } else {
                $message = "Terjadi kesalahan saat mengonfirmasi pengembalian.";
            }
        }
    }

    // Redirect ke halaman yang sama dengan pesan
    header("Location: orders.php?message=" . urlencode($message));
    exit;
}

// Ambil semua data pesanan
$resultOrders = $pesanan->getAllOrders();
?>

<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Kelola Pesanan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/order.css">
</head>

<body>
    <?php include('../components/sidebar.php'); ?>

    <div class="container py-5">
        <h1 class="text-center">Kelola Pesanan</h1>
        <table class="table table-bordered mt-4">
            <thead>
                <tr class="table-primary text-center">
                    <th>ID Pesanan</th>
                    <th>Nama Penyewa</th>
                    <th>Nomor Telepon</th>
                    <th>Kendaraan</th>
                    <th>Metode Pembayaran</th>
                    <th>Total</th>
                    <th>Status</th>
                    <th>Bukti Transaksi</th>
                    <th>Aksi</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($resultOrders->num_rows > 0): ?>
                    <?php while ($order = $resultOrders->fetch_assoc()): ?>
                        <?php if ($order['status_pesanan'] !== 'riwayat'): ?> <!-- Kondisi untuk tidak menampilkan pesanan dengan status "riwayat" -->
                            <tr class="text-center">
                                <td><?php echo $order['id_pesanan']; ?></td>
                                <td><?php echo htmlspecialchars($order['nama_penyewa']); ?></td>
                                <td><?php echo htmlspecialchars($order['nomor_telepon']); ?></td>
                                <td><?php echo htmlspecialchars($order['nama_kendaraan']); ?></td>
                                <td><?php echo htmlspecialchars($order['nama_pembayaran']); ?></td>
                                <td>Rp <?php echo number_format($order['total_pesanan'], 0, ',', '.'); ?></td>
                                <td>
                                    <?php if ($order['status_pesanan'] === 'belum bayar'): ?>
                                        <span class="badge bg-warning">Belum Bayar</span>
                                    <?php elseif ($order['status_pesanan'] === 'pending'): ?>
                                        <span class="badge bg-info">Pending</span>
                                    <?php elseif ($order['status_pesanan'] === 'sukses'): ?>
                                        <span class="badge bg-success">Sukses</span>
                                    <?php elseif ($order['status_pesanan'] === 'riwayat'): ?>
                                        <span class="badge bg-secondary">Riwayat</span>
                                    <?php else: ?>
                                        <span class="badge bg-danger">Batal</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <?php if (!empty($order['bukti_pembayaran'])): ?>
                                        <img src="../../<?php echo htmlspecialchars($order['bukti_pembayaran']); ?>" class="img-thumbnail">
                                    <?php else: ?>
                                        <span class="text-danger">Tidak Ada Bukti</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <div class="btn-group" role="group" aria-label="Aksi Pesanan">
                                        <?php if ($order['status_pesanan'] === 'pending'): ?>
                                            <button type="button" class="btn btn-success btn-sm" onclick="confirmAction('acc', <?php echo $order['id_pesanan']; ?>)">ACC</button>
                                            <button type="button" class="btn btn-danger btn-sm" onclick="confirmAction('cancel', <?php echo $order['id_pesanan']; ?>)">Cancel</button>
                                        <?php endif; ?>

                                        <?php if ($order['status_pesanan'] === 'sukses'): ?>
                                            <button type="button" class="btn btn-secondary btn-sm" onclick="confirmAction('riwayat', <?php echo $order['id_pesanan']; ?>)">Konfirmasi Pengembalian</button>
                                        <?php endif; ?>

                                        <button type="button" class="btn btn-danger btn-sm" onclick="confirmAction('delete', <?php echo $order['id_pesanan']; ?>)">Hapus</button>
                                    </div>
                                </td>
                            </tr>
                        <?php endif; ?>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="9" class="text-center">Tidak ada pesanan</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <script>
        // Periksa apakah ada pesan dari PHP (menggunakan URL query parameter)
        window.onload = function() {
            const urlParams = new URLSearchParams(window.location.search);
            const message = urlParams.get('message');

            if (message) {
                // Tampilkan SweetAlert jika ada pesan
                Swal.fire({
                    icon: 'success',
                    title: 'Success',
                    text: message,
                    showConfirmButton: true,
                });
            }
        };

        function confirmAction(action, orderId) {
            let actionText = '';
            switch (action) {
                case 'acc':
                    actionText = 'konfirmasi pesanan ini';
                    break;
                case 'cancel':
                    actionText = 'batalkan pesanan ini';
                    break;
                case 'delete':
                    actionText = 'hapus pesanan ini';
                    break;
                case 'riwayat':
                    actionText = 'konfirmasi pengembalian kendaraan';
                    break;
            }

            Swal.fire({
                title: 'Apakah Anda yakin?',
                text: `Anda akan ${actionText}.`,
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Ya',
                cancelButtonText: 'Batal',
            }).then((result) => {
                if (result.isConfirmed) {
                    // Redirect ke URL dengan action dan id_pesanan
                    window.location.href = `orders.php?action=${action}&id_pesanan=${orderId}`;
                }
            });
        }
    </script>
</body>

</html>