<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/Product.php';

// Periksa apakah pengguna telah login
if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php'); // Redirect ke halaman login jika belum login
    exit;
}

// Periksa apakah role user adalah admin
if ($_SESSION['user']['role'] !== 'admin') {
    header('Location: ../public/home.php'); // Redirect ke halaman utama jika bukan admin
    exit;
}

// Instansiasi class Product
$product = new Product();

// Tambah produk
if (isset($_POST['add_product'])) {
    $nama_kendaraan = $_POST['nama_kendaraan'];
    $stok_kendaraan = $_POST['stok_kendaraan'];
    $harga_kendaraan = $_POST['harga_kendaraan'];

    // Upload gambar
    $img_kendaraan = $_FILES['img_kendaraan']['name'];
    $target_dir = "../../assets/img/";
    $target_file = $target_dir . basename($img_kendaraan);

    if (move_uploaded_file($_FILES['img_kendaraan']['tmp_name'], $target_file)) {
        // Simpan path relatif ke database
        $path_in_database = "assets/img/" . $img_kendaraan;
        $product->addProduct($nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $path_in_database);
        $_SESSION['product_added'] = true;
        header('Location: produk.php'); // Redirect setelah berhasil menambah produk
        exit;
    } else {
        echo "Failed to upload image.";
    }
}

// Edit produk
if (isset($_POST['edit_product'])) {
    $id_kendaraan = $_POST['id_kendaraan'];
    $nama_kendaraan = $_POST['nama_kendaraan'];
    $stok_kendaraan = $_POST['stok_kendaraan'];
    $harga_kendaraan = $_POST['harga_kendaraan'];

    // Cek apakah gambar baru diupload
    $img_kendaraan = $_POST['old_img_kendaraan']; // Gambar lama
    if (!empty($_FILES['img_kendaraan']['name'])) {
        $img_kendaraan = $_FILES['img_kendaraan']['name'];
        $target_dir = "../../assets/img/";
        $target_file = $target_dir . basename($img_kendaraan);

        // Upload gambar baru
        if (move_uploaded_file($_FILES['img_kendaraan']['tmp_name'], $target_file)) {
            $img_kendaraan = "assets/img/" . $img_kendaraan; // Path baru untuk database
        }
    }

    // Update produk
    $product->updateProduct($id_kendaraan, $nama_kendaraan, $stok_kendaraan, $harga_kendaraan, $img_kendaraan);
    $_SESSION['product_edited'] = true;
    header('Location: produk.php'); // Redirect setelah berhasil mengedit produk
    exit;
}

// Hapus produk
if (isset($_GET['delete_id'])) {
    $id_kendaraan = $_GET['delete_id'];
    $product->deleteProduct($id_kendaraan);
    $_SESSION['product_deleted'] = true;
    header('Location: produk.php'); // Redirect setelah berhasil menghapus produk
    exit;
}

// Ambil semua produk
$products = $product->getAllProducts();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Produk</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/produk.css">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>

<body>

    <!-- Sidebar -->
    <?php include('../components/sidebar.php'); ?>

    <div class="container mt-4">
        <h1 class="text-center">Produk</h1>

        <!-- Button untuk menambah produk -->
        <button class="btn btn-success mb-3" data-bs-toggle="modal" data-bs-target="#addProductModal">Tambah Produk</button>

        <!-- Modal untuk tambah produk -->
        <div class="modal fade" id="addProductModal" tabindex="-1" aria-labelledby="addProductModalLabel"
            aria-hidden="true">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="addProductModalLabel">Tambah Produk Baru</h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <form action="produk.php" method="POST" enctype="multipart/form-data">
                            <div class="mb-3">
                                <label for="nama_kendaraan" class="form-label">Nama Produk</label>
                                <input type="text" class="form-control" id="nama_kendaraan" name="nama_kendaraan"
                                    required>
                            </div>
                            <div class="mb-3">
                                <label for="stok_kendaraan" class="form-label">Stock</label>
                                <input type="number" class="form-control" id="stok_kendaraan" name="stok_kendaraan"
                                    required>
                            </div>
                            <div class="mb-3">
                                <label for="harga_kendaraan" class="form-label">Harga</label>
                                <input type="number" class="form-control" id="harga_kendaraan" name="harga_kendaraan"
                                    required>
                            </div>
                            <div class="mb-3">
                                <label for="img_kendaraan" class="form-label">Foto</label>
                                <input type="file" class="form-control" id="img_kendaraan" name="img_kendaraan"
                                    required>
                            </div>
                            <button type="submit" name="add_product" class="btn btn-success">Tambah Produk</button>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        <!-- Tabel untuk menampilkan produk -->
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Name</th>
                    <th>Image</th>
                    <th>Stock</th>
                    <th>Price</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($products)): ?>
                    <?php foreach ($products as $row): ?>
                        <tr>
                            <td><?php echo $row['id_kendaraan']; ?></td>
                            <td><?php echo $row['nama_kendaraan']; ?></td>
                            <td><img src="../../<?php echo $row['img_kendaraan']; ?>" width="100"></td>
                            <td><?php echo $row['stok_kendaraan']; ?></td>
                            <td>Rp <?php echo number_format($row['harga_kendaraan'], 0, ',', '.'); ?></td>
                            <td>
                                <!-- Button untuk edit produk -->
                                <button class="btn btn-primary btn-sm" data-bs-toggle="modal"
                                    data-bs-target="#editProductModal<?php echo $row['id_kendaraan']; ?>">Edit</button>

                                <!-- Modal untuk edit produk -->
                                <div class="modal fade" id="editProductModal<?php echo $row['id_kendaraan']; ?>" tabindex="-1"
                                    aria-labelledby="editProductModalLabel" aria-hidden="true">
                                    <div class="modal-dialog">
                                        <div class="modal-content">
                                            <div class="modal-header">
                                                <h5 class="modal-title" id="editProductModalLabel">Edit Product</h5>
                                                <button type="button" class="btn-close" data-bs-dismiss="modal"
                                                    aria-label="Close"></button>
                                            </div>
                                            <div class="modal-body">
                                                <form action="produk.php" method="POST" enctype="multipart/form-data">
                                                    <input type="hidden" name="id_kendaraan"
                                                        value="<?php echo $row['id_kendaraan']; ?>">
                                                    <input type="hidden" name="old_img_kendaraan"
                                                        value="<?php echo $row['img_kendaraan']; ?>">
                                                    <div class="mb-3">
                                                        <label for="nama_kendaraan" class="form-label">Nama Produk</label>
                                                        <input type="text" class="form-control" id="nama_kendaraan"
                                                            name="nama_kendaraan" value="<?php echo $row['nama_kendaraan']; ?>" required>
                                                    </div>
                                                    <div class="mb-3">
                                                        <label for="stok_kendaraan" class="form-label">Stock</label>
                                                        <input type="number" class="form-control" id="stok_kendaraan"
                                                            name="stok_kendaraan" value="<?php echo $row['stok_kendaraan']; ?>" required>
                                                    </div>
                                                    <div class="mb-3">
                                                        <label for="harga_kendaraan" class="form-label">Harga</label>
                                                        <input type="number" class="form-control" id="harga_kendaraan"
                                                            name="harga_kendaraan" value="<?php echo $row['harga_kendaraan']; ?>" required>
                                                    </div>
                                                    <div class="mb-3">
                                                        <label for="img_kendaraan" class="form-label">Foto</label>
                                                        <input type="file" class="form-control" id="img_kendaraan"
                                                            name="img_kendaraan">
                                                    </div>
                                                    <button type="submit" name="edit_product" class="btn btn-primary">Update</button>
                                                </form>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <!-- Button untuk hapus produk -->
                                <button class="btn btn-danger btn-sm" onclick="confirmDelete(<?php echo $row['id_kendaraan']; ?>)">Hapus</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        function confirmDelete(productId) {
            Swal.fire({
                title: 'Apakah Anda yakin?',
                text: 'Produk ini akan dihapus!',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Hapus',
                cancelButtonText: 'Batal',
            }).then((result) => {
                if (result.isConfirmed) {
                    window.location.href = 'produk.php?delete_id=' + productId;
                }
            });
        }

        <?php if (isset($_SESSION['product_added'])): ?>
            Swal.fire({
                icon: 'success',
                title: 'Produk berhasil ditambahkan!',
                showConfirmButton: false,
                timer: 1500
            });
            <?php unset($_SESSION['product_added']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['product_edited'])): ?>
            Swal.fire({
                icon: 'success',
                title: 'Produk berhasil diupdate!',
                showConfirmButton: false,
                timer: 1500
            });
            <?php unset($_SESSION['product_edited']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['product_deleted'])): ?>
            Swal.fire({
                icon: 'success',
                title: 'Produk berhasil dihapus!',
                showConfirmButton: false,
                timer: 1500
            });
            <?php unset($_SESSION['product_deleted']); ?>
        <?php endif; ?>
    </script>

</body>
</html>