<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/pesanan.php';

// Periksa apakah pengguna telah login
if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php'); // Redirect ke halaman login jika belum login
    exit;
}

// Periksa apakah role user adalah admin
if ($_SESSION['user']['role'] !== 'admin') {
    header('Location: ../public/home.php'); // Redirect ke halaman utama jika bukan admin
    exit;
}

// Inisialisasi koneksi database
$database = new Database();
$conn = $database->getConnection();

// Inisialisasi kelas Pesanan
$pesanan = new Pesanan($conn);

// Ambil semua data pesanan yang statusnya 'riwayat'
$resultOrders = $pesanan->getOrdersByStatus('riwayat');

// Proses penghapusan riwayat pesanan
if (isset($_GET['delete_id'])) {
    $id_pesanan = $_GET['delete_id'];
    $pesanan->deleteOrder($id_pesanan); // Fungsi untuk menghapus pesanan di database
    header('Location: riwayat.php?delete_success=true'); // Redirect dengan parameter success
    exit;
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Riwayat Pesanan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/order.css">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>

<body>
    <?php include('../components/sidebar.php'); ?>

    <div class="container py-5">
        <h1 class="text-center">Riwayat Pesanan</h1>
        <table class="table table-bordered mt-4">
            <thead>
                <tr class="table-primary text-center">
                    <th>ID Pesanan</th>
                    <th>Nama Penyewa</th>
                    <th>Nomor Telepon</th>
                    <th>Kendaraan</th>
                    <th>Metode Pembayaran</th>
                    <th>Total</th>
                    <th>Status</th>
                    <th>Bukti Transaksi</th>
                    <th>Aksi</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($resultOrders->num_rows > 0): ?>
                    <?php while ($order = $resultOrders->fetch_assoc()): ?>
                        <tr class="text-center">
                            <td><?php echo $order['id_pesanan']; ?></td>
                            <td><?php echo htmlspecialchars($order['nama_penyewa']); ?></td>
                            <td><?php echo htmlspecialchars($order['nomor_telepon']); ?></td>
                            <td><?php echo htmlspecialchars($order['nama_kendaraan']); ?></td>
                            <td><?php echo htmlspecialchars($order['nama_pembayaran']); ?></td>
                            <td>Rp <?php echo number_format($order['total_pesanan'], 0, ',', '.'); ?></td>
                            <td>
                                <?php if ($order['status_pesanan'] === 'riwayat'): ?>
                                    <span class="badge bg-secondary">Riwayat</span>
                                <?php endif; ?>
                            </td>
                            <td>
                                <?php if (!empty($order['bukti_pembayaran'])): ?>
                                    <img src="../../<?php echo htmlspecialchars($order['bukti_pembayaran']); ?>"
                                        class="img-thumbnail" width="100">
                                <?php else: ?>
                                    <span class="text-danger">Tidak Ada Bukti</span>
                                <?php endif; ?>
                            </td>
                            <td>
                                <!-- Button untuk hapus pesanan -->
                                <button class="btn btn-danger btn-sm" onclick="confirmDelete(<?php echo $order['id_pesanan']; ?>)">Hapus</button>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="9" class="text-center text-danger">Tidak ada riwayat pesanan</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script>
        // Fungsi untuk konfirmasi penghapusan menggunakan SweetAlert
        function confirmDelete(orderId) {
            Swal.fire({
                title: 'Apakah Anda yakin?',
                text: 'Riwayat pesanan ini akan dihapus!',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Hapus',
                cancelButtonText: 'Batal',
            }).then((result) => {
                if (result.isConfirmed) {
                    // Jika dikonfirmasi, redirect ke halaman ini dengan parameter delete_id
                    window.location.href = 'riwayat.php?delete_id=' + orderId;
                }
            });
        }

        // Menampilkan notifikasi sukses jika ada parameter delete_success di URL
        <?php if (isset($_GET['delete_success']) && $_GET['delete_success'] == 'true'): ?>
            Swal.fire({
                title: 'Sukses!',
                text: 'Riwayat pesanan berhasil dihapus.',
                icon: 'success',
                confirmButtonText: 'OK'
            });
        <?php endif; ?>
    </script>
</body>
</html>