<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/Auth.php';

$auth = new Auth();
$error = '';
$success = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Ambil data inputan dari form
    $username = trim($_POST['username']);
    $email = trim($_POST['email']);
    $password = trim($_POST['password']);

    // Validasi inputan
    if (empty($username) || empty($email) || empty($password)) {
        $error = 'Semua field harus diisi.';
    } else {
        // Panggil fungsi register dari class Auth
        $result = $auth->register($username, $email, $password);

        // Cek hasil dari registrasi
        if (is_array($result)) {
            if ($result['success']) {
                $success = $result['message']; // Jika berhasil
                header("Location: login.php"); // Redirect ke login
                exit;
            } else {
                $error = $result['message']; // Jika gagal, tampilkan pesan error
            }
        } else {
            $error = 'Terjadi kesalahan pada sistem.'; // Jika terjadi error sistem
        }
    }
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register - Sewa Kendaraan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">

    <style>
       /* Body Style: Full-screen with background image */
       body { 
            background: url('../../assets/img/A.png') no-repeat center center fixed;
            background-size: cover;
            font-family: 'Arial', sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 60vh; /* Ensure full height */
            margin: 0;
        }

        /* Container Style */
        .container {
            max-width: 500px; /* Limit the max width for larger screens */
            width: 100%; /* Allow the container to scale down on smaller screens */
            height: 350px;
        }

        /* Card Style */
        .card {
            background-color: rgba(0, 0, 0, 0.6); /* Darker background */
            border-radius: 20px;
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.3);
            padding: 35px;
            color: white;
        }

        .registrasi {
            color: #f1f1f1;
            font-size: 2rem;
            font-weight: 600;
        }

        /* Logo Image */
        .foto { 
            filter: drop-shadow(0 0 15px rgba(0, 0, 0, 0.5)); 
            margin-bottom: 0px;
        }

        /* Label & Input Fields */
        label { 
            color: #f1f1f1;
            font-weight: 500;
        }

        .form-control {
            border-radius: 10px;
            background-color: #f1f1f1;
            color: #333;
            border: none;
            padding: 10px;
            font-size: 1rem;
            transition: all 0.3s ease;
        }

        .form-control:focus {
            background-color: #ffffff;
            border-color: #007bff;
            box-shadow: 0 0 5px rgba(0, 123, 255, 0.8);
        }

        /* Button Style */
        .btn-primary {
            background-color: #007bff;
            border-color: #0069d9;
            padding: 10px;
            font-size: 1rem;
            border-radius: 10px;
            transition: all 0.3s ease;
        }

        .btn-primary:hover {
            background-color: #0069d9;
            border-color: #0056b3;
            cursor: pointer;
        }

        /* Footer Link */
        .footer-link {
            text-align: center;
            font-size: 0.9rem;
        }

        .footer-link a {
            color: #d1d1d1;
            font-weight: bold;
            text-decoration: none;
            transition: all 0.3s ease;
        }

        .footer-link a:hover {
            color: #007bff;
            text-decoration: underline;
        }

        /* Error Message */
        .alert {
            font-size: 0.9rem;
        }

        /* Media Query for Mobile Responsiveness */
        @media (max-width: 767px) {
            .login {
                font-size: 1.5rem;
            }

            .card {
                padding: 20px;
            }

            .foto {
                width: 120px;
            }

            .btn-primary {
                padding: 12px;
                font-size: 0.9rem;
            }

            .container {
                width: 90%; /* Make container more responsive on small screens */
            }
        }
    </style>
</head>
<body>

    <div class="container">
        <div class="row justify-content-center">
            <div class="col-md-12">
                <!-- Logo Section -->
                <div class="text-center">
                    <img src="../../assets/img/Logo_S2R.png" class="foto" width="150" alt="Logo Sewa Kendaraan">
                </div>

                <!-- Card for Register Form -->
                <div class="card">
                    <h4 class="login text-center mb-4">Registrasi</h4>

                    <!-- Display error or success message -->
                    <?php if ($error): ?>
                        <div class="alert alert-danger"><?= $error ?></div>
                    <?php elseif ($success): ?>
                        <div class="alert alert-success"><?= $success ?></div>
                    <?php endif; ?>

                    <!-- Registration Form -->
                    <form method="POST">
                        <div class="mb-3">
                            <label for="username" class="form-label">Username</label>
                            <input type="text" class="form-control" name="username" required>
                        </div>

                        <div class="mb-3">
                            <label for="email" class="form-label">Email</label>
                            <input type="email" class="form-control" name="email" required>
                        </div>

                        <div class="mb-3">
                            <label for="password" class="form-label">Password</label>
                            <input type="password" class="form-control" name="password" required>
                        </div>

                        <button type="submit" class="btn btn-success w-100 mt-3">Daftar</button>
                    </form>

                    <!-- Footer Link -->
                    <div class="footer-link mt-3">
                        <a href="login.php"> Login </a>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
