<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/pesanan.php';
require_once '../../classes/Pembayaran.php';

if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php');
    exit;
}

$message = '';
$idPesanan = isset($_GET['id_pesanan']) ? $_GET['id_pesanan'] : null;

// Pastikan ID pesanan valid
if (!$idPesanan) {
    die("Pesanan tidak ditemukan.");
}

$pesanan = new Pesanan();
$pesananDetail = $pesanan->getOrderById($idPesanan);

// Pastikan pesanan ditemukan
if (!$pesananDetail) {
    die("Pesanan tidak ditemukan.");
}

// Buat instance kelas Pembayaran
$db = new Database();
$conn = $db->getConnection();
$pembayaran = new Pembayaran($conn);

// Ambil data pembayaran berdasarkan id_pembayaran dari pesanan
$pembayaranDetail = $pembayaran->getPembayaranById($pesananDetail['id_pembayaran']);

// Menentukan rekening tujuan berdasarkan informasi dari database
$rekeningTujuan = '';
$namaPenerima = '';
if ($pembayaranDetail) {
    $rekeningTujuan = $pembayaranDetail['no_rek']; // Ambil nomor rekening dari database
    $namaPenerima = $pembayaranDetail['nama_penerima']; // Ambil nama penerima dari database
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $buktiPembayaran = '';
    if (isset($_FILES['bukti_pembayaran']['name']) && $_FILES['bukti_pembayaran']['error'] == 0) {
        $fileTmp = $_FILES['bukti_pembayaran']['tmp_name'];
        $fileName = time() . '_' . $_FILES['bukti_pembayaran']['name'];
        $uploadDir = '../../assets/img/bukti_transaksi/';

        // Pastikan folder tujuan ada
        if (!is_dir($uploadDir)) {
            mkdir($uploadDir, 0777, true);
        }

        // Validasi apakah file yang diupload adalah gambar
        $fileType = mime_content_type($fileTmp);
        $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];

        if (in_array($fileType, $allowedTypes)) {
            // Pindahkan file ke folder tujuan
            if (move_uploaded_file($fileTmp, $uploadDir . $fileName)) {
                // Mengupdate bukti pembayaran ke database
                if ($pesanan->updateBuktiPembayaran($idPesanan, 'assets/img/bukti_transaksi/' . $fileName)) {
                    // Update status pesanan menjadi "pending"
                    if ($pesanan->updateOrderStatus($idPesanan, 'pending')) {
                        $message = 'Bukti pembayaran berhasil diupload dan status pesanan berubah menjadi pending!';
                    } else {
                        $message = 'Terjadi kesalahan saat memperbarui status pesanan.';
                    }

                    // Arahkan ke halaman pesanan-saya.php setelah berhasil
                    header('Location: pesanan-saya.php');
                    exit;
                } else {
                    $message = 'Terjadi kesalahan saat mengupdate bukti pembayaran ke database.';
                }
            } else {
                $message = 'Terjadi kesalahan saat mengupload bukti pembayaran.';
            }
        } else {
            $message = 'Hanya file gambar yang diperbolehkan (JPEG, PNG, GIF).';
        }
    } else {
        $message = 'Tidak ada file yang diupload atau terjadi kesalahan saat mengupload.';
    }
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Bayar Pesanan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            font-family: Arial, sans-serif;
            background-color: rgb(11, 112, 155);
        }

        .container {
            margin-top: 50px;
            max-width: 600px;
        }

        .struk-card {
            background-color: #f8f9fa;
            border: 1px solid #ccc;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.1);
        }

        .struk-card h4 {
            font-size: 1.5rem;
            margin-bottom: 15px;
        }

        .struk-card p {
            font-size: 1.1rem;
            margin-bottom: 10px;
        }

        .upload-btn {
            background-color:rgb(11, 112, 155);
            color: white;
            font-size: 1.2rem;
            width: 100%;
            padding: 10px;
            border-radius: 5px;
            border: none;
        }

        .upload-btn:hover {
            background-color:rgb(11, 112, 155);
        }

        .alert {
            margin-top: 20px;
        }

        .card-header {
            background-color:rgb(11, 112, 155);
            color: white;
        }
    </style>
</head>
<body>

<div class="container">
    <div class="struk-card">
        <div class="card-header text-center">
            <h4>Bayar Pesanan</h4>
        </div>

        <?php if ($message): ?>
            <div class="alert alert-info text-center">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>

        <div class="mb-4">
            <h5>Nomor Rekening Tujuan:</h5>
            <p><strong><?php echo htmlspecialchars($rekeningTujuan); ?></strong></p>

            <h5>Nama Penerima:</h5>
            <p><strong><?php echo htmlspecialchars($namaPenerima); ?></strong></p>
        </div>

        <form method="POST" enctype="multipart/form-data">
            <div class="mb-3">
                <label for="bukti_pembayaran" class="form-label">Upload Bukti Pembayaran</label>
                <input type="file" class="form-control" id="bukti_pembayaran" name="bukti_pembayaran" accept="image/*" required>
            </div>
            <button type="submit" class="upload-btn">Upload Bukti Pembayaran</button>
        </form>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
