<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/Product.php';

// Periksa apakah pengguna sudah login
if (!isset($_SESSION['user'])) {
    header("Location: index.php");
    exit();
}

// Inisialisasi kelas Product
$product = new Product();

// Mengambil semua data kendaraan
$vehicles = $product->getAllProducts();

if (!$vehicles) {
    $vehicles = []; // Jika tidak ada data, set menjadi array kosong
}

$user = $_SESSION['user']; // Data pengguna dari sesi
?>

<!DOCTYPE html>
<html lang="id">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Home - Sewa Kendaraan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/style.css">
</head>

<body>

    <!-- Navbar -->
    <?php include('../components/navbar.php') ?>

    <!-- Header -->
    <?php include('../components/header.php') ?>

    <!-- Daftar Kendaraan -->
    <div class="container py-5 mt-5" id="vehicles">
        <h2 class="text-center mb-5 title-vehicles">Daftar Kendaraan</h2>
        <p class="text-center text-muted">Pilih kendaraan terbaik untuk perjalanan Anda!</p>
        <div class="row g-4">
            <?php foreach ($vehicles as $vehicle): ?>
                <div class="col-md-4">
                    <div class="card vehicle-card shadow-lg wow fadeInUp" data-wow-delay="0.2s">
                        <img src="../../<?php echo htmlspecialchars($vehicle['img_kendaraan']); ?>"
                            class="card-img-top vehicle-img rounded-top"
                            alt="<?php echo htmlspecialchars($vehicle['nama_kendaraan']); ?>" />
                        <div class="card-body">
                            <h5 class="card-title vehicle-title"><?php echo htmlspecialchars($vehicle['nama_kendaraan']); ?>
                            </h5>
                            <p class="card-text">Harga per hari: Rp <strong
                                    class="text-success"><?php echo number_format($vehicle['harga_kendaraan'], 0, ',', '.'); ?></strong>
                            </p>
                            <p class="card-text">Stok tersedia: <span
                                    class="badge bg-<?php echo $vehicle['stok_kendaraan'] > 0 ? 'success' : 'danger'; ?>"><?php echo $vehicle['stok_kendaraan'] > 0 ? 'Ada' : 'Habis'; ?></span>
                            </p>
                            <?php if ($vehicle['stok_kendaraan'] > 0): ?>
                                <a href="memesan.php?id=<?php echo $vehicle['id_kendaraan']; ?>" class="btn btn-success">
                                    Pesan Sekarang
                                </a>
                            <?php else: ?>
                                <span class="btn btn-secondary disabled w-100">Tidak Tersedia</span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>

    <!-- Tentang Kami (About Us) -->
    <div class="container my-5" id="about-us">
        <h2 class="text-center text-primary mb-4">Tentang Kami</h2>
        <p class="text-center text-muted">S2R Rental adalah perusahaan yang menyediakan layanan sewa kendaraan
            berkualitas dengan harga yang terjangkau. Kami berkomitmen untuk memberikan kenyamanan dan kepuasan bagi
            pelanggan kami dengan berbagai pilihan motor. Kami menjamin pelayanan yang cepat, aman, dan terpercaya.</p>
    </div>

    <!-- Syarat & Ketentuan -->
    <div class="container my-5" id="syaratketentuan">
        <h2 class="text-center text-primary mb-4">Peraturan Penggunaan</h2>
        <ul class="list-group">
            <li class="list-group-item">Pengguna harus berusia minimal 18 tahun.</li>
            <li class="list-group-item">Informasi yang diberikan harus akurat dan benar.</li>
            <li class="list-group-item">Website tidak bertanggung jawab atas kerugian akibat kesalahan pengguna.</li>
        </ul>
    </div>

    <!-- Footer -->
    <?php include('../components/footer.php'); ?>

    <script src="../../assets/js/bootstrap.bundle.min.js"></script>
</body>

</html>