<?php
session_start();
require_once '../../classes/database.php';
require_once '../../classes/Product.php';
require_once '../../classes/pesanan.php';
require_once '../../classes/Pembayaran.php';

if (!isset($_SESSION['user'])) {
    header('Location: auth/login.php');
    exit;
}

$vehicleId = $_GET['id'] ?? null;
if (!$vehicleId) {
    die("Kendaraan tidak ditemukan.");
}

$kendaraan = new Product();
$vehicle = $kendaraan->getProductById($vehicleId);
if (!$vehicle || $vehicle['stok_kendaraan'] <= 0) {
    die("Kendaraan tidak tersedia.");
}

$pembayaran = new Pembayaran();
$paymentMethods = $pembayaran->getAllPembayaran();

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = htmlspecialchars($_POST['name']);
    $phone = htmlspecialchars($_POST['phone']);
    $startDate = $_POST['start_date'];
    $endDate = $_POST['end_date'];
    $paymentMethod = $_POST['payment_method'];

    if (strtotime($endDate) <= strtotime($startDate)) {
        die("Tanggal akhir harus lebih besar dari tanggal mulai.");
    }

    $totalDays = ceil((strtotime($endDate) - strtotime($startDate)) / (60 * 60 * 24));
    $totalPrice = $vehicle['harga_kendaraan'] * $totalDays;

    $userId = $_SESSION['user']['id'];
    $pesanan = new Pesanan();

    if ($pesanan->buatPesanan($userId, $name, $phone, $startDate, $endDate, $vehicleId, $paymentMethod, $totalPrice)) {
        header('Location: pesanan-saya.php?status=success');
        exit;
    } else {
        echo "<div class='alert alert-danger'>Terjadi kesalahan saat memproses pesanan. Silakan coba lagi.</div>";
    }
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pesan Kendaraan</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <style>
       /* General Body Styling */
       body {
            background: linear-gradient(135deg, #1e3c72, #2a5298); /* Biru gelap */
            min-height: 100vh;
            display: flex;
            align-items: center;
            justify-content: center;
            font-family: 'Roboto', sans-serif;
        }

        /* Form Container */
        .form-container {
            max-width: 500px;
            background: #fff;
            padding: 40px;
            border-radius: 10px;
            box-shadow: 0px 8px 15px rgba(0, 0, 0, 0.2);
        }

        /* Header Styling */
        h1 {
            text-align: center;
            color: #1e3c72; /* Warna biru lebih gelap */
            font-weight: bold;
            margin-bottom: 20px;
        }

        h3 {
            text-align: center;
            color: #2a5298; /* Biru yang lebih terang */
            margin-bottom: 20px;
        }

        .form-label {
            font-weight: bold;
            color: #1e3c72;
        }

        /* Buttons */
        .btn-primary {
            background: linear-gradient(90deg, #2a5298, #1e3c72);
            border: none;
            color: #fff;
            padding: 12px 20px;
            border-radius: 30px;
            font-size: 16px;
            font-weight: bold;
            transition: all 0.3s ease;
        }

        .btn-primary:hover {
            background: linear-gradient(90deg, #1e3c72, #2a5298);
            transform: scale(1.05);
        }

        /* Form Controls */
        .form-control {
            border-radius: 20px;
            padding: 12px 15px;
            font-size: 16px;
            margin-bottom: 20px;
        }

        .form-control:focus {
            box-shadow: 0px 0px 8px rgba(108, 99, 255, 0.5);
        }

        /* Alerts */
        .alert {
            font-size: 14px;
            text-align: center;
            border-radius: 20px;
        }

        /* Price Information */
        .price-info {
            text-align: center;
            font-size: 18px;
            font-weight: bold;
            color: #2a5298;
        }
    </style>
</head>
<body>
    <?php include('../components/navbar.php'); ?>
    <div class="form-container">
        <h1><i class="fas fa-motorcycle"></i> Pesan Kendaraan</h1>
        <h3><?= htmlspecialchars($vehicle['nama_kendaraan']); ?></h3>
        <p class="price-info">Harga per hari: Rp <?= number_format($vehicle['harga_kendaraan'], 0, ',', '.'); ?></p>
        <p class="price-info">Stok tersedia: <?= $vehicle['stok_kendaraan']; ?></p>

        <?php if (isset($_GET['status']) && $_GET['status'] === 'success'): ?>
            <script>
                Swal.fire({
                    icon: 'success',
                    title: 'Pesanan Berhasil',
                    text: 'Pesanan kendaraan Anda berhasil dibuat!',
                    confirmButtonColor: '#3085d6',
                    confirmButtonText: 'OK'
                }).then((result) => {
                    if (result.isConfirmed) {
                        window.location.href = 'pesanan-saya.php';
                    }
                });
            </script>
        <?php endif; ?>

        <form method="POST" onsubmit="return validateDates()">
            <div class="mb-3">
                <label for="name" class="form-label"><i class="fas fa-user"></i> Nama Penyewa</label>
                <input type="text" name="name" class="form-control" placeholder="Masukkan nama Anda" required>
            </div>
            <div class="mb-3">
                <label for="phone" class="form-label"><i class="fas fa-phone"></i> Nomor Telepon</label>
                <input type="text" name="phone" class="form-control" placeholder="Masukkan nomor telepon Anda" required>
            </div>
            <div class="mb-3">
                <label for="start_date" class="form-label"><i class="fas fa-calendar-alt"></i> Tanggal Mulai Sewa</label>
                <input type="date" id="start_date" name="start_date" class="form-control" 
                       value="<?= date('Y-m-d'); ?>" 
                       min="<?= date('Y-m-d'); ?>" required>
            </div>
            <div class="mb-3">
                <label for="end_date" class="form-label"><i class="fas fa-calendar-check"></i> Tanggal Akhir Sewa</label>
                <input type="date" id="end_date" name="end_date" class="form-control" 
                       value="<?= date('Y-m-d', strtotime('+1 day')); ?>" 
                       min="<?= date('Y-m-d', strtotime('+1 day')); ?>" required>
            </div>
            <div class="mb-3">
                <label for="payment_method" class="form-label"><i class="fas fa-credit-card"></i> Metode Pembayaran</label>
                <select name="payment_method" class="form-control" required>
                    <option value="">Pilih Metode Pembayaran</option>
                    <?php foreach ($paymentMethods as $method): ?>
                        <option value="<?= $method['id_pembayaran']; ?>">
                            <?= htmlspecialchars($method['nama_pembayaran']); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <button type="submit" class="btn btn-primary w-100" onclick="return confirm('Apakah Anda yakin ingin memesan kendaraan ini?')">Pesan Sekarang</button>
        </form>
    </div>

    <script>
        // JavaScript untuk validasi tanggal
        function validateDates() {
            const startDate = document.getElementById('start_date').value;
            const endDate = document.getElementById('end_date').value;

            if (new Date(endDate) <= new Date(startDate)) {
                Swal.fire({
                    icon: 'error',
                    title: 'Tanggal Tidak Valid',
                    text: 'Tanggal akhir harus lebih besar dari tanggal mulai.',
                    confirmButtonColor: '#d33',
                    confirmButtonText: 'OK'
                });
                return false;
            }
            return true;
        }

        // Otomatis perbarui tanggal akhir minimal saat tanggal mulai diubah
        document.getElementById('start_date').addEventListener('change', function() {
            const startDate = this.value;
            const endDateInput = document.getElementById('end_date');
            
            // Set minimal tanggal akhir ke tanggal mulai + 1 hari
            const minEndDate = new Date(startDate);
            minEndDate.setDate(minEndDate.getDate() + 1);
            endDateInput.min = minEndDate.toISOString().split('T')[0];

            // Reset nilai end_date jika kurang dari minEndDate
            if (new Date(endDateInput.value) <= minEndDate) {
                endDateInput.value = minEndDate.toISOString().split('T')[0];
            }
        });
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>