<?php
session_start(); // Memulai session

// Periksa apakah pengguna sudah login
if (!isset($_SESSION['user'])) {
    header('Location: ../auth/login.php'); // Redirect jika belum login
    exit;
}

// Ambil data dari session
$is_logged_in = isset($_SESSION['user']);
$userId = $_SESSION['user']['id']; // Gunakan key 'id' sesuai session login

// Sertakan file Database
require_once '../../classes/database.php';

// Buat instance Database dan dapatkan koneksi
$db = new Database();
$conn = $db->getConnection();

// Ambil data pesanan user (kecuali yang berstatus 'riwayat')
$queryOrders = "SELECT p.*, k.nama_kendaraan 
                FROM tbl_pesanan p
                JOIN tbl_kendaraan k ON p.id_kendaraan = k.id_kendaraan
                WHERE p.id_user = ? AND p.status_pesanan != 'riwayat'
                ORDER BY p.created_at DESC";
$stmt = $conn->prepare($queryOrders);
$stmt->bind_param("i", $userId);
$stmt->execute();
$resultOrders = $stmt->get_result();

// Proses pembatalan pesanan
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['cancel_order'])) {
    $orderId = $_POST['id_pesanan'];

    // Cek apakah pesanan berstatus "belum bayar"
    $queryCheck = "SELECT * FROM tbl_pesanan WHERE id_pesanan = ? AND id_user = ? AND status_pesanan = 'belum bayar'";
    $stmt = $conn->prepare($queryCheck);
    $stmt->bind_param("ii", $orderId, $userId);
    $stmt->execute();
    $resultCheck = $stmt->get_result();
    $order = $resultCheck->fetch_assoc();

    if ($order) {
        // Update stok kendaraan
        $updateStockQuery = "UPDATE tbl_kendaraan SET stok_kendaraan = stok_kendaraan + 1 WHERE id_kendaraan = ?";
        $stmt = $conn->prepare($updateStockQuery);
        $stmt->bind_param("i", $order['id_kendaraan']);
        $stmt->execute();

        // Ubah status pesanan menjadi batal
        $updateOrderQuery = "UPDATE tbl_pesanan SET status_pesanan = 'batal' WHERE id_pesanan = ?";
        $stmt = $conn->prepare($updateOrderQuery);
        $stmt->bind_param("i", $orderId);
        $stmt->execute();

        $message = "Pesanan berhasil dibatalkan.";
        $status = "success";
    } else {
        $message = "Pesanan tidak dapat dibatalkan.";
        $status = "error";
    }
}

// Tutup koneksi database
$db->closeConnection();
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pesanan Saya</title>
    <link href="../../assets/img/Logo_S2R.png" rel="icon">
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <link rel="stylesheet" href="../../assets/css/style.css">
    <!-- SweetAlert2 -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <!-- Background Style -->
    <style>
        body {
            background-color: #001f3f; /* Warna biru agak gelap */
            color: #ffffff; /* Warna teks putih agar terlihat jelas */
        }
    </style>
</head>

<body>
    <!-- Navbar -->
    <?php include("../components/navbar.php"); ?>

    <!-- Container -->
    <div class="container my-5 py-5">
        <h1 class="text-center mb-4">Pesanan Saya</h1>

        <!-- Pesan Notifikasi -->
        <?php if (isset($message)): ?>
            <div class="alert alert-info" role="alert">
                <?= htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>

        <!-- Tabel Pesanan -->
        <?php if ($resultOrders->num_rows > 0): ?>
            <div class="table-responsive">
                <table class="table table-bordered table-striped">
                    <thead class="table-dark">
                        <tr>
                            <th>ID Pesanan</th>
                            <th>Nama Kendaraan</th>
                            <th>Tanggal Pinjam</th>
                            <th>Tanggal Kembali</th>
                            <th>Total Pesanan</th>
                            <th>Status</th>
                            <th>Aksi</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php while ($row = $resultOrders->fetch_assoc()): ?>
                            <tr>
                                <td><?= htmlspecialchars($row['id_pesanan']); ?></td>
                                <td><?= htmlspecialchars($row['nama_kendaraan']); ?></td>
                                <td><?= htmlspecialchars($row['tgl_pinjam']); ?></td>
                                <td><?= htmlspecialchars($row['tgl_kembali']); ?></td>
                                <td>Rp <?= number_format($row['total_pesanan'], 0, ',', '.'); ?></td>
                                <td>
                                    <span class="badge 
                                        <?= $row['status_pesanan'] === 'belum bayar' ? 'bg-danger' : ($row['status_pesanan'] === 'pending' ? 'bg-warning text-dark' : 'bg-success'); ?>">
                                        <?= htmlspecialchars(ucfirst($row['status_pesanan'])); ?>
                                    </span>
                                </td>
                                <td>
                                    <?php if ($row['status_pesanan'] === 'belum bayar'): ?>
                                        <button class="btn btn-danger btn-sm cancel-button" data-id="<?= htmlspecialchars($row['id_pesanan']); ?>">Batalkan</button>
                                        <a href="bayar.php?id_pesanan=<?= htmlspecialchars($row['id_pesanan']); ?>" class="btn btn-primary btn-sm">Bayar</a>
                                    <?php elseif ($row['status_pesanan'] === 'pending'): ?>
                                        <button class="btn btn-secondary btn-sm" disabled>Menunggu Konfirmasi</button>
                                    <?php elseif ($row['status_pesanan'] === 'sukses'): ?>
                                        <button class="btn btn-success btn-sm" disabled>Lunas</button>
                                    <?php elseif ($row['status_pesanan'] === 'batal'): ?>
                                        <button class="btn btn-secondary btn-sm" disabled>Batal</button>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endwhile; ?>
                    </tbody>
                </table>
            </div>
        <?php else: ?>
            <div class="alert alert-warning text-center" role="alert">
                Belum ada pesanan.
            </div>
        <?php endif; ?>
    </div>

    <!-- SweetAlert notifikasi -->
    <script>
        document.querySelectorAll('.cancel-button').forEach(button => {
            button.addEventListener('click', function() {
                const orderId = this.getAttribute('data-id');
                Swal.fire({
                    title: 'Apakah Anda yakin?',
                    text: 'Pesanan ini akan dibatalkan dan stok kendaraan akan dikembalikan!',
                    icon: 'warning',
                    showCancelButton: true,
                    confirmButtonText: 'Ya, Batalkan!',
                    cancelButtonText: 'Tidak, Batalkan'
                }).then((result) => {
                    if (result.isConfirmed) {
                        const form = document.createElement('form');
                        form.method = 'POST';
                        form.action = ''; // Tempatkan form ini di halaman yang sama
                        const input = document.createElement('input');
                        input.type = 'hidden';
                        input.name = 'cancel_order';
                        input.value = '1';
                        form.appendChild(input);
                        const orderInput = document.createElement('input');
                        orderInput.type = 'hidden';
                        orderInput.name = 'id_pesanan';
                        orderInput.value = orderId;
                        form.appendChild(orderInput);
                        document.body.appendChild(form);
                        form.submit();
                    }
                });
            });
        });
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js" integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous"></script>
</body>

</html>
